Welcome to the Scikit-HEP project!
==================================

You can find a little introduction to the project in the :ref:`About <about>` page.
To get started, first :ref:`install the skhep module <installation>`
and then read the :ref:`main documentation <documentation>`.

If you have ideas concerning the development of the project,
or if there is a feature missing you'd like to see,
you are most welcome to :ref:`contribute to Scikit-HEP <contributing>`.
Please also check out the :ref:`list of affiliated packages <affiliations>`.

.. Here's some maths: :math:`\decay{D^{0}}{h^{+}h^{-}}`, and :math:`\pT` and :math:`x`.

.. toctree::
   :hidden:
   :maxdepth: 2

   about.rst
   installation.rst
   help.rst
   documentation.rst
   contributing.rst
   affiliations.rst


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
